@@ -1,5 +1,12 @@
 from sensiml.client import SensiML
-from sensiml.widgets import DashBoard
+
+try:
+    from sensiml.widgets import DashBoard
+
+    __all__ = ["SensiML", "DashBoard"]
+except ImportError:
+    # dev version fails here so lets import a dummy
+    __all__ = ["SensiML"]
 
 
 try:
@@ -10,7 +17,4 @@ except:
     pass
 
 name = "sensiml"
-
-
-__version__ = "2020.1.3"
-__all__ = ["SensiML", "DashBoard"]
+__version__ = "2020.2.0"
