@@ -2,9 +2,7 @@ from __future__ import print_function
 import json
 import requests
 from pandas import DataFrame
-from IPython.core.display import HTML
 import time
-import warnings
 import logging
 from six.moves import input
 
@@ -28,14 +26,6 @@ def prompt_for_overwrite(file_that_exists):
     return False
 
 
-def make_ipython_link(url, link_text):
-    """Makes a href URL link for iPython Notebook HTML with a given URL.
-
-    Takes url and link text parameters to format the string properly.
-    """
-    return HTML('<a href="https://{0}">{1}</a>'.format(url, link_text))
-
-
 def data_response(response_json):
     """ handle response with data from kbserver """
     data = response_json.get("data", None)
