@@ -4,9 +4,11 @@ import re
 from tempfile import NamedTemporaryFile
 from appdirs import user_config_dir
 import json
-from qgrid import show_grid
+try:
+    from qgrid import show_grid
+except:
+    pass
 
-import numpy as np
 import pandas as pd
 from pandas import DataFrame
 
@@ -17,12 +19,12 @@ from sensiml.datamanager import (
     PipelineSeeds,
     Projects,
     SegmenterSet,
-    CaptureConfigurations,
 )
 from sensiml.datamanager.knowledgepack import get_knowledgepack, get_knowledgepacks
 from sensiml.datasets import DataSets
 from sensiml.connection import Connection
-from sensiml.base.exceptions import *
+
+# from sensiml.base.exceptions import *
 from sensiml.pipeline import Pipeline
 from sensiml.base.snippets import Snippets, function_help
 from sensiml.datamanager.captures import CaptureExistsError
@@ -192,7 +194,7 @@ class SensiML(object):
                         "SUBTYPE": f.subtype,
                         "KP FUNCTION": f.has_c_version,
                     }
-                    for f in self.functions.get_functions()
+                    for name, f in self.functions.function_list.items()
                 ]
             )
             .sort_values(by=["TYPE", "SUBTYPE"])
@@ -231,17 +233,18 @@ class SensiML(object):
         """
         return self.projects.build_project_dict()
 
-    def list_segmenters(self):
+    def list_segmenters(self,):
         if self._project is None:
             print("project must be set to list segmenters.")
             return None
 
-        segmenters = SegmenterSet(
-            self._connection, self._project).get_set()
-        if not len(segmenters):
+        segmenters = SegmenterSet(self._connection, self._project)
+
+        if not len(segmenters.objs):
             print("No segmenters stored on the Cloud.")
             return None
-        return DataFrame(segmenters)[["name", "id", "custom", "parent"]]
+
+        return segmenters.to_dataframe()
 
     def list_seeds(self):
         """Lists all of the pipeline seeds on SensiML Cloud
@@ -273,8 +276,7 @@ class SensiML(object):
 
         if unnamed:
             return knowledgepack_list[
-                ["Name", "Created", "Project", "Pipeline",
-                    "kp_uuid", "kp_description"]
+                ["Name", "Created", "Project", "Pipeline", "kp_uuid", "kp_description"]
             ]
 
         return knowledgepack_list[knowledgepack_list["Name"] != ""][
@@ -385,8 +387,7 @@ class SensiML(object):
     @pipeline.setter
     def pipeline(self, name):
         if self._project is None:
-            raise Exception(
-                "Project must be set before a pipeline can be created")
+            raise Exception("Project must be set before a pipeline can be created")
 
         self._pipeline = Pipeline(self, name=name)
 
@@ -401,6 +402,7 @@ class SensiML(object):
         combine_labels=None,
         force=False,
         renderer=None,
+        capture_configurations=""
     ):
         """Create a query to use as input data in a pipeline.
 
@@ -415,7 +417,9 @@ class SensiML(object):
         Returns:
             object: Returns a query object that was created.
         """
+
         query = self.project.queries.get_query_by_name(name)
+        
         new = False
         if query is not None and not force:
             raise QueryExistsException(
@@ -426,6 +430,9 @@ class SensiML(object):
             query.metadata_columns.clear()
             query.metadata_filter = ""
             query.label_column = ""
+            query.capture_configurations = ""
+            query.segmenter=None
+            
         else:
             query = self.project.queries.new_query()
             query.name = name
@@ -449,6 +456,9 @@ class SensiML(object):
         if combine_labels:
             query.combine_labels = combine_labels
 
+        if capture_configurations:
+            query.capture_configurations = capture_configurations
+
         query.segmenter = segmenter
 
         if new:
@@ -472,8 +482,7 @@ class SensiML(object):
         if name[-4:] != ".csv":
             name = "{}.csv".format(name)
 
-        feature_file = self._project._feature_files.get_featurefile_by_name(
-            name)
+        feature_file = self._project._feature_files.get_featurefile_by_name(name)
         if feature_file is None:
             new = True
             feature_file = self._project.featurefiles.new_featurefile()
@@ -518,8 +527,8 @@ class SensiML(object):
         for i in range(100):
             results = query.get_feature_statistics()
 
-            if results.get('results', None):
-                return pd.DataFrame(results['results'])
+            if results.get("results", None):
+                return pd.DataFrame(results["results"])
             sleep(5)
 
         print("Not able to reach the results in the expected time. ")
@@ -574,14 +583,12 @@ class SensiML(object):
                 file_metadata = []
                 if os.path.exists(
                     os.path.join(
-                        basedir, "metadata", os.path.basename(capture)[
-                            :-3] + "dcl"
+                        basedir, "metadata", os.path.basename(capture)[:-3] + "dcl"
                     )
                 ):
                     with open(
                         os.path.join(
-                            basedir, "metadata", os.path.basename(capture)[
-                                :-3] + "dcl"
+                            basedir, "metadata", os.path.basename(capture)[:-3] + "dcl"
                         ),
                         "r",
                     ) as f:
