@@ -545,6 +545,28 @@ class KnowledgePack(VisualizeMixin):
             **kwargs
         )
 
+    def download_source(
+        self, folder="", run_async=True, platform=None, renderer=None, *args, **kwargs
+    ):
+        """Calls the server to generate static library image based on device config.
+
+        Args:
+            folder (str): Folder to save to if not generating a link
+
+        Returns:
+            str: Denoting success, or link to file download
+        """
+        return self._download(
+            folder=folder,
+            bin_or_lib="source",
+            run_async=run_async,
+            platform=platform,
+            renderer=renderer,
+            *args,
+            **kwargs
+        )
+
+
     def download_binary(
         self, folder="", run_async=True, platform=None, renderer=None, *args, **kwargs
     ):
@@ -622,8 +644,7 @@ class KnowledgePack(VisualizeMixin):
         else:
             config = self.get_sandbox_device_config()
 
-        bin_lib = "Binary" if bin_or_lib == "bin" else "Library"
-        print("Building Binary with configuration")
+        print("Generating {} with configuration".format(bin_or_lib))
         for key in config:
             print("{} : {}".format(key, config[key]))
 
