@@ -1,4 +1,3 @@
-import matplotlib.pyplot as plt
 
 
 class DataSegment(object):
@@ -15,14 +14,18 @@ class DataSegment(object):
         return " ".join(["{}:{}".format(k, v) for k, v in self._metadata.items()])
 
 
-class DataSegments(list):
+class DataSegments(dict):
+
     def plot(self, **kwargs):
-        for segment in self.__iter__():
+        import matplotlib as plt
+        plt.rcParams.update({'figure.max_open_warning': 0})
+        for _, segment in self.items():
             segment.plot(**kwargs)
 
 
+
 def to_datasegments(data, metdata_columns, label_column):
-    """ Converts a dataframe into a data setments """
+    """ Converts a dataframe into a data segments object"""
 
     group_columns = metdata_columns + [label_column]
     g = data.groupby(group_columns)
@@ -38,7 +41,7 @@ def to_datasegments(data, metdata_columns, label_column):
 
         tmp_df = g.get_group(key)[data_columns]
 
-        ds.append(DataSegment(tmp_df, metadata, metadata[label_column]))
+        ds[tmp_df['uuid']] = DataSegment(tmp_df, metadata, metadata[label_column])
 
     return ds
 
