@@ -1,12 +1,8 @@
-import uuid
 import itertools
 import copy
 import json
-from tempfile import NamedTemporaryFile
-from os import remove
 import time
 import logging
-from pandas import DataFrame, Series
 from requests.exceptions import HTTPError
 from six import string_types
 import numpy as np
@@ -14,7 +10,6 @@ import numpy as np
 from sensiml.base.exceptions import DuplicateValueError
 import sensiml.base.utility as utility
 from sensiml.base.snippets import generate_pipeline
-from sensiml.base.exceptions import *
 
 try:
     from sensiml.visualize import Visualize
@@ -88,8 +83,6 @@ class Pipeline(object):
             print("Error: data_columns must be a list.")
             return
 
-        upper_case_data_columns = set(map(lambda x: x.upper(), self.data_columns))
-
     @property
     def label_column(self):
         return self._label_column
@@ -1199,11 +1192,12 @@ class Pipeline(object):
     def features_to_tensor(
         self,
         feature_vectors,
-        validate=0.2,
-        test=0.0,
+        validate=.1,
+        test=.1,
         label=None,
         feature_columns=None,
         class_map=None,
+        dtype=int
     ):
 
         if label is None:
@@ -1238,7 +1232,7 @@ class Pipeline(object):
         # Calculate the indices of each section.
         train = 1.0 - (test + validate)
         TRAIN_SPLIT = int(train * SAMPLES)
-        TEST_SPLIT = int(0.2 * SAMPLES + TRAIN_SPLIT)
+        TEST_SPLIT = int(test * SAMPLES + TRAIN_SPLIT)
 
         # Use np.split to chop our data into three parts.
         # The second argument to np.split is an array of indices where the data will be
@@ -1247,52 +1241,20 @@ class Pipeline(object):
         y_train, y_test, y_validate = np.split(
             y_values_encoded, [TRAIN_SPLIT, TEST_SPLIT]
         )
+                            
+        print("-----  Summary  -----")
+        print("Class Map:", class_map)
+        print("Train:\n total: ", x_train.shape[0])
+        print(" by class:",y_train.sum(axis=0))
 
-        return x_train, x_test, x_validate, y_train, y_test, y_validate, class_map
+        print("Validate:\n total: ", x_validate.shape[0])
+        print(" by class:",y_validate.sum(axis=0))
 
-        if label is None:
-            label = self._label_column
-
-        if class_map is None:
-            class_map = {k: v for v, k in enumerate(feature_vectors[label].unique())}
-
-        num_classes = len(class_map)
-
-        feature_vectors["__CAT_LABEL__"] = feature_vectors[label].apply(
-            lambda x: class_map[x]
-        )
-
-        if feature_columns is None:
-            feature_columns = [
-                col for col in feature_vectors.columns if col[:4] == "gen_"
-            ]
-
-        resample = feature_vectors.sample(frac=1, axis=0).reset_index(drop=True)
-        resample_features = resample[feature_columns]
-
-        y_values_encoded = get_one_hot(
-            resample["__CAT_LABEL__"].values, num_classes
-        ).reshape((resample.shape[0], 1), num_classes)
-        x_values = resample_features.values[:, :].reshape(
-            resample_features.shape[0], resample_features.shape[1], 1
-        )
-
-        SAMPLES = x_values.shape[0]
-        # Calculate the indices of each section.
-        train = 1.0 - (test + validate)
-        TRAIN_SPLIT = int(train * SAMPLES)
-        TEST_SPLIT = int(0.2 * SAMPLES + TRAIN_SPLIT)
-
-        # Use np.split to chop our data into three parts.
-        # The second argument to np.split is an array of indices where the data will be
-        # split. We provide two indices, so the data will be divided into three chunks.
-        x_train, x_test, x_validate = np.split(x_values, [TRAIN_SPLIT, TEST_SPLIT])
-        y_train, y_test, y_validate = np.split(
-            y_values_encoded, [TRAIN_SPLIT, TEST_SPLIT]
-        )
-
-        return x_train, x_test, x_validate, y_train, y_test, y_validate, class_map
+        print("Train:\n total: ", x_test.shape[0])
+        print(" by class:",y_test.sum(axis=0))     
 
+        return x_train.astype(dtype), x_test.astype(dtype), x_validate.astype(dtype), y_train.astype(dtype), y_test.astype(dtype), y_validate.astype(dtype), class_map
+        
 
 def get_contract_column_type(input_contract):
 
