@@ -80,11 +80,13 @@ class AutoSenseWidget(BaseWidget):
         survivor_rate = self._w_survivor_rate.value
         reset = self._c_reset.value
         allow_unk = self._c_allow_unk.value
+        single_model = self._c_single_model.value
         hierarchical_model = self._c_hierarchical_model.value
         balanced_data = self._c_balanced_data.value
         optimization_metric = self._w_optimization_metric.value.lower()
         demean_segments = self._c_strip_mean.value
         outlier_filter = self._c_outlier_filter.value
+
         if self._w_combine_labels.value:
             combine_labels = json.loads(self._w_combine_labels.value)
         else:
@@ -119,13 +121,14 @@ class AutoSenseWidget(BaseWidget):
             "population_size": population_size,
             "mutation_rate": mutation_rate,
             "recreation_rate": recreation_rate,
-            "survior_rate": survivor_rate,
+            "survivor_rate": survivor_rate,
             "allow_unknown": allow_unk,
             "validation_method": validation_method,
             "balanced_data": balanced_data,
             "demean_segments": demean_segments,
             "outlier_filter": outlier_filter,
-            "allow_hierarchical_model": hierarchical_model,
+            "single_model": single_model,
+            "hierarchical_multi_model": hierarchical_model,
             "prediction_target(%)": {optimization_metric: 100},
             "hardware_target": {"classifiers_sram": classifiers_sram},
             "combine_labels": combine_labels,
@@ -143,6 +146,18 @@ class AutoSenseWidget(BaseWidget):
             )
             return
 
+        if params['single_model']==False and params['hierarchical_multi_model']==False:
+            self.renderer.render(
+                "\nERROR: Knowledge Pack Architecture was not selected. Select 'Single Model', 'Hierarchical Multi-Model' or Both.\n"
+            )
+            return
+
+        if sum([params['mutation_rate'], params['recreation_rate'], params['survivor_rate']])>0.95:
+            self.renderer.render(
+                "\nERROR: Summation of recreation_rate, mutation_rate and survivor_rate cannot be greater than 0.95.\n"
+            )
+            return
+           
         self._dsk.project.query_optimize()
 
         self._dsk.pipeline.reset()
@@ -158,6 +173,7 @@ class AutoSenseWidget(BaseWidget):
                 "generatorset"
             ] = self.custom_feature_generator.get_fature_generator()
 
+
         print("Auto Sense Params", params)
         self._dsk.pipeline.describe()
 
@@ -443,10 +459,17 @@ class AutoSenseWidget(BaseWidget):
             layout=info_layout,
         )
 
+        self._info_single_model = widgets.Button(
+            icon="question",
+            disabled=True,
+            tooltip="Optimize the prediction results by creating a knowledge pack from a single model.",
+            layout=info_layout,
+        )
+
         self._info_hierarchical_model = widgets.Button(
             icon="question",
             disabled=True,
-            tooltip="Optimize the prediction results by creating Hierarchical Binary Models.",
+            tooltip="Optimize the prediction results by creating a knowledge pack from the hierarchical multi-models.",
             layout=info_layout,
         )
 
@@ -556,8 +579,12 @@ class AutoSenseWidget(BaseWidget):
 
         self._c_allow_unk = Checkbox(description="Allow Unknown", value=False)
 
+        self._c_single_model = Checkbox(
+            description="Single Model", value=True
+        )
+
         self._c_hierarchical_model = Checkbox(
-            description="Hierarchical Model Optimization", value=False
+            description="Hierarchical Multi-Model", value=False
         )
 
         self._c_balanced_data = Checkbox(description="Balance Data", value=False)
@@ -770,10 +797,6 @@ class AutoSenseWidget(BaseWidget):
                             [self._c_balanced_data, self._info_balanced_data],
                             layout=Layout(align_self="flex-start"),
                         ),
-                        HBox(
-                            [self._c_hierarchical_model, self._info_hierarchical_model],
-                            layout=Layout(align_self="flex-start"),
-                        ),
                         HBox(
                             [self._c_outlier_filter, self._info_outlier_filter],
                             layout=Layout(align_self="flex-start"),
@@ -813,31 +836,53 @@ class AutoSenseWidget(BaseWidget):
                         ),
                     ]
                 ),
-                VBox(
+
+                HBox(
                     [
-                        widgets.HTML("<b>Genetic Search Setttings</b>"),
-                        HBox(
-                            [self._w_population_size, self._info_population],
-                            layout=Layout(align_self="flex-start"),
-                        ),
-                        HBox(
-                            [self._w_iterations, self._info_iterations],
-                            layout=Layout(align_self="flex-start"),
-                        ),
-                        HBox(
-                            [self._w_recreation_rate, self._info_recreation_rate],
-                            layout=Layout(align_self="flex-start"),
-                        ),
-                        HBox(
-                            [self._w_mutation_rate, self._info_mutation_rate],
-                            layout=Layout(align_self="flex-start"),
-                        ),
-                        HBox(
-                            [self._w_survivor_rate, self._info_survivor_rate],
-                            layout=Layout(align_self="flex-start"),
+                        VBox(
+                            [
+                                widgets.HTML("<b>Genetic Search Setttings</b>"),
+                                HBox(
+                                    [self._w_population_size, self._info_population],
+                                    layout=Layout(align_self="flex-start"),
+                                ),
+                                HBox(
+                                    [self._w_iterations, self._info_iterations],
+                                    layout=Layout(align_self="flex-start"),
+                                ),
+                                HBox(
+                                    [self._w_recreation_rate, self._info_recreation_rate],
+                                    layout=Layout(align_self="flex-start"),
+                                ),
+                                HBox(
+                                    [self._w_mutation_rate, self._info_mutation_rate],
+                                    layout=Layout(align_self="flex-start"),
+                                ),
+                                HBox(
+                                    [self._w_survivor_rate, self._info_survivor_rate],
+                                    layout=Layout(align_self="flex-start"),
+                                ),
+                            ]
                         ),
+
+                        VBox(
+                            [
+                                widgets.HTML("<b>Knowledge Pack Architecture Setting</b>"),
+                                HBox(
+                                    [self._c_single_model, self._info_single_model],
+                                    layout=Layout(align_self="flex-start"),
+                                ),
+                                HBox(
+                                    [self._c_hierarchical_model, self._info_hierarchical_model],
+                                    layout=Layout(align_self="flex-start"),
+                                ),
+
+                            ]
+                        )
+
                     ]
-                ),
+                )
+
             ]
         )
 
