@@ -28,6 +28,7 @@ from IPython.display import display
 from bqplot import OrdinalScale, LinearScale, Bars, Lines, Axis, Figure
 from sensiml.widgets.renderers import WidgetAttributeRenderer
 from pandas import DataFrame
+import json
 
 
 def get_item(x, index, default=None):
@@ -80,6 +81,25 @@ class QueryWidget:
 
         self._refresh()
 
+    
+    def check_capture_configurations_for_unique_sample_rate(self, capture_configurations_names):
+        sample_rate_list = []
+        for capture_configuration_name in capture_configurations_names:
+            c = self._dsk.project.capture_configurations.get_capture_configuration_by_name(
+                    capture_configuration_name)
+            sample_rate = c.configuration['capture_sources'][0]['sample_rate']
+            sample_rate_list.append(sample_rate)
+
+        if len(np.unique(sample_rate_list)) > 1:
+            error_msg = 'The capture configurations selected for this query have different sample rates. A query can only be created from capture configurations with the same sample rate.'
+            self.renderer.render("\n\n" + error_msg + "\n")
+            raise Exception(error_msg)
+
+    def get_uuid_capture_configurations(self, capture_configurations_names):
+        df_capture_configurations = self._dsk.list_capture_configurations()
+        return df_capture_configurations[
+            df_capture_configurations.Name.isin(capture_configurations_names)].UUID.to_list()
+
     def add_query(self, create=False, force=False):
         if self._dsk is None:
             return
@@ -95,6 +115,12 @@ class QueryWidget:
         metadata_columns = self._items.get("metadata_columns", None)
         sensor_columns = self._items.get("sensor_columns", None)
         metadata_filter = self._items.get("metadata_filter", "")
+        
+        self.check_capture_configurations_for_unique_sample_rate(
+            self._items.get("capture_configuration", None))
+
+        capture_configuration_items = self.get_uuid_capture_configurations(
+                    self._items.get("capture_configuration", None))
 
         if not segmenter_name:
             self.renderer.render("No segmenter specified")
@@ -128,12 +154,13 @@ class QueryWidget:
 
         if isinstance(sensor_columns, str):
             sensor_columns = sensor_columns.split(",")
-
+        
         try:
             self.renderer.render("Creating Query.")
             self.query = self._dsk.create_query(
                 query_name,
                 columns=sorted(sensor_columns),
+                capture_configurations=capture_configuration_items,
                 metadata_columns=[m for m in metadata_columns if m != label_column],
                 segmenter=segmenter_id,
                 metadata_filter=metadata_filter,
@@ -306,6 +333,12 @@ class QueryWidget:
         self._sensor_columns_mselector.options = sensor_items
         self._sensor_columns_mselector_create.options = sensor_items
         self._sensor_columns_mselector_create.value = sensor_items
+        
+        capture_configurations_items = sorted(self._dsk.list_capture_configurations()['Name'].to_list())
+        self._capture_configurations_mselector.options = capture_configurations_items
+        self._capture_configurations_mselector_create.options = capture_configurations_items
+        self._capture_configurations_mselector_create.value = capture_configurations_items
+        
         self._query_select.options = [""] + sorted(
             list(set(queries)), key=lambda s: s.lower()
         )
@@ -320,8 +353,8 @@ class QueryWidget:
         return True
 
     def populate_items(self, populate_create=False):
-
         self._items["sensor_columns"] = self._sensor_columns_mselector.value
+        self._items["capture_configuration"] = self._capture_configurations_mselector.value
         self._items["metadata_columns"] = self._metadta_items_mselect.value
         self._items["label_column"] = self._label_column_select.value
         self._items["segmenter_name"] = self._segmenter_select.value
@@ -331,13 +364,21 @@ class QueryWidget:
 
         if populate_create:
             self._items["sensor_columns"] = self._sensor_columns_mselector_create.value
+            self._items["capture_configuration"] = self._capture_configurations_mselector_create.value
             self._items["metadata_columns"] = self._metadata_items_mselect_create.value
             self._items["label_column"] = self._label_column_select_create.value
             self._items["segmenter_name"] = self._segmenter_select_create.value
             self._items["query_name"] = self._query_name_text.value
             self._items["metadata_filter"] = self._metadata_filter_text_create.value
 
+    def get_name_capture_configurations(self, capture_configurations_uuid):
+        capture_configurations_uuid = json.loads(capture_configurations_uuid)
+        df_capture_configurations = self._dsk.list_capture_configurations()
+        return df_capture_configurations[
+            df_capture_configurations.UUID.isin(capture_configurations_uuid)].Name.to_list()
+        
     def populate_query(self, change=None):
+        
         self.populate_items()
 
         self.query = self._dsk.project.queries.get_query_by_name(
@@ -350,6 +391,7 @@ class QueryWidget:
             seg = self._dsk.list_segmenters()
 
             self._sensor_columns_mselector.value = qdict["sensor_columns"]
+            self._capture_configurations_mselector.value = self.get_name_capture_configurations( qdict["capture_configurations"])            
             self._metadta_items_mselect.value = qdict["metadata_columns"]
             self._label_column_select.value = qdict["label_column"]
             self._metadata_filter_text.value = qdict["metadata_filter"]
@@ -377,7 +419,6 @@ class QueryWidget:
 
     def create_widget(self, name=""):
         # refresh the project so that the most up to date values are shown
-
         self._query_name_text = Text(description="Name")
         self._query_select = Dropdown(description="Name")
         self._segmenter_select = Dropdown(description="Session")
@@ -391,8 +432,13 @@ class QueryWidget:
         self._label_column_select_create = Dropdown(description="Label")
         self._metadta_items_mselect = SelectMultiple(description="Metadata")
         self._metadata_items_mselect_create = SelectMultiple(description="Metadata")
+        
         self._sensor_columns_mselector = SelectMultiple(description="Sources")
         self._sensor_columns_mselector_create = SelectMultiple(description="Sources")
+
+        self._capture_configurations_mselector = SelectMultiple(description="Configuration")
+        self._capture_configurations_mselector_create = SelectMultiple(description="Configuration")
+
         self._metadata_filter_text = Text(description="Query Filter")
         self._metadata_filter_text_create = Text(description="Query Filter")
         self._add_query = Button(
@@ -463,6 +509,7 @@ class QueryWidget:
                                 self._label_column_select,
                                 self._metadta_items_mselect,
                                 self._sensor_columns_mselector,
+                                self._capture_configurations_mselector,
                                 self._metadata_filter_text,
                                 self._plot_type,
                                 HBox([self._delete_query, self._update_query]),
@@ -480,6 +527,7 @@ class QueryWidget:
                                 self._label_column_select_create,
                                 self._metadata_items_mselect_create,
                                 self._sensor_columns_mselector_create,
+                                self._capture_configurations_mselector_create,
                                 self._metadata_filter_text_create,
                                 self._add_query,
                             ]
